import axios from 'axios'
import { Message, MessageBox } from 'element-ui'
import { getToken } from '@/utils/auth'

// create an axios instance
const service = axios.create({
  //本地测试地址
  // baseURL: 'http://192.168.100.208:9083/admin', 
  //发布地址
  baseURL: 'http://47.103.79.143:9085/admin', 
  timeout: 10000 // request timeout
})

// request interceptor
service.interceptors.request.use(config => {
  // Do something before request is sent
  if (getToken()) {
    config.headers['Authorization'] = getToken() // 让每个请求携带token-- ['X-Token']为自定义key 请根据实际情况自行修改
  }
  return config
}, error => {
  // Do something with request error
  console.log(error) // for debug
  Promise.reject(error)
})

// respone interceptor
service.interceptors.response.use(
  response => {
    const res = response.data
    let errmsg = res.errmsg;
    if (res.errno !== 0) {
      if(res.errno==503){
        MessageBox.alert('超时自动退出系统，请重新登录', '已退出', {
          confirmButtonText: '重新登录',
          type: 'error'
        }).then(() => {
            //本地地址
            // location.href = 'http://192.168.100.208:8080/oneportal/login';
            //发布地址
            location.href = 'http://dgtcloud.dgtis.com/oneportal/login';
        })
      }else{
        Message({
          message: errmsg,
          type: 'error',
          duration: 2 * 1000
        })
      }
      return Promise.reject('error')
    } else {
      return response
    }
  }, error => {
    console.log('err' + error)// for debug
    Message({
      message: '连接超时',
      type: 'error',
      duration: 2 * 1000
    })
    return Promise.reject(error)
  })

export default service
